==> ksystemlog-trinity-3.5.13.2.tar.xz: ksystemlog-trinity-3.5.13.2/ksystemlog/src/slotLogAction.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/


#ifndef _SLOT_LOG_ACTION_H_
#define _SLOT_LOG_ACTION_H_

#include <kaction.h>

class KSystemLog;


class SlotLogAction : public TQObject {
	
	Q_OBJECT
  TQ_OBJECT
	
	public:
		SlotLogAction(KSystemLog* parent);
		
	public slots:
		
		/**
		 * This header contains the normal version of the main slot
		 */
		void slotLogAction(KAction::ActivationReason reason, TQt::ButtonState state);
	
	private:
		KSystemLog* parent;
};

#endif

==> ksystemlog-trinity_14.1.0.orig.tar.xz: ksystemlog-trinity-14.1.0/ksystemlog/src/slotLogAction.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/


#ifndef _SLOT_LOG_ACTION_H_
#define _SLOT_LOG_ACTION_H_

#include <tdeaction.h>

class KSystemLog;


class SlotLogAction : public TQObject {
	
	Q_OBJECT
  
	
	public:
		SlotLogAction(KSystemLog* parent);
		
	public slots:
		
		/**
		 * This header contains the normal version of the main slot
		 */
		void slotLogAction(TDEAction::ActivationReason reason, TQt::ButtonState state);
	
	private:
		KSystemLog* parent;
};

#endif
